@@ -308,6 +308,15 @@ class Client:
         cache = self._object_buffer.buffer_send_object(obj, name)
         return ObjectReference(cache.object_name, cache.object_id, sum(map(len, cache.object_bytes)))
 
+    def clear(self):
+        """
+        clear all resources used by the client, this will cancel all running futures and invalidate all existing object
+        references
+        """
+
+        self._future_manager.cancel_all_futures()
+        self._object_buffer.clear()
+
     def disconnect(self):
         """
         disconnect from connected scheduler, this will not shut down the scheduler
@@ -524,7 +533,7 @@ class Client:
         parent_task_priority = self.__get_parent_task_priority()
 
         if parent_task_priority is not None:
-            task_priority = parent_task_priority - 1
+            task_priority = parent_task_priority + 1
         else:
             task_priority = 0
 
