@@ -3,7 +3,8 @@ import unittest
 
 from scaler import Client, SchedulerClusterCombo
 from scaler.utility.logging.utility import setup_logger
-from tests.utility import get_available_tcp_port, logging_test_name
+from scaler.utility.network_util import get_available_tcp_port
+from tests.utility import logging_test_name
 
 
 class TestProtected(unittest.TestCase):
